%% phdth.cls
%% LaTeX class file sitable for a PhD. thesis
%% Miroslav Broz (miroslav.broz@email.cz), Jan 26th 2006

%% AMS packages...

\usepackage{amssymb,amsbsy}

%% page mirror

\setlength\headheight{7.5pt}
\setlength\headsep{10.5pt}
\setlength\topskip{7.5pt}
\setlength\footskip{18pt}

\setlength\textheight{58\baselineskip}
\addtolength\textheight{\topskip}
\setlength\textwidth{160mm}
\setlength\topmargin{-1.2cm}
\setlength\oddsidemargin{-.0cm}
\setlength\evensidemargin{-.0cm}

\setlength\marginparwidth{0pt}
\setlength\marginparsep{10pt}
\setlength\marginparsep{0pt}

\setlength\columnsep{10pt}
\setlength\columnseprule{0pt}

\setlength\footnotesep{0pt}
\setlength{\skip\footins}{9pt plus 3pt}

%% paragraphs

\setlength{\parindent}{\baselineskip}	% 1 ctvercik
\overfullrule=5pt

%% chapters and sections

\let\oldsection=\section
\def\chapter#1{%
  \newpage
  \ifodd\value{page}\else\leavevmode\newpage\fi
  \oldsection{#1}%
}
\let\section=\subsection
\let\subsection=\subsubsection
\def\subsubsection#1{\paragraph{{\bf #1.}}}

%% indices

\def\idx#1{#1\index{#1}}
\def\idxname#1{\index{{\sc #1}}}

%% float parameters

\renewcommand{\topfraction}{0.9}	% max fraction of floats at top
\renewcommand{\bottomfraction}{0.8}	% max fraction of floats at bottom
\setcounter{topnumber}{5}		% Parameters for TEXT pages (not float pages):
\setcounter{bottomnumber}{5}
\setcounter{totalnumber}{5}		% 2 may work better
\setcounter{dbltopnumber}{5}		% for 2-column pages
\renewcommand{\dbltopfraction}{0.9}	% fit big float above 2-col. text
\renewcommand{\textfraction}{0.07}	% allow minimal text w. figs
% Parameters for FLOAT pages (not text pages):
\renewcommand{\floatpagefraction}{0.7}	% require fuller float pages
% N.B.: floatpagefraction MUST be less than topfraction !!
\renewcommand{\dblfloatpagefraction}{0.7}	% require fuller float pages
% remember to use [htp] or [htpb] for placement

%% short commands

\newdimen\tmpdim

\def\etal{\kern-.1em\hbox{\it et al.}}
\def\and{\&}
\def\name#1{{\sc #1}}

\def\swiftrmvsy{{\tt swift\_rmvsy}}
\def\d{{\rm d}}
\def\e{\mathop{\rm e}\nolimits}
\def\I{{\rm i}}
%\def\vec#1{{\fam\vefam\tenve #1}}
\def\vec#1{{\bf #1}}
\font\calb=eusb10
\def\vecc#1{\hbox{\calb #1}}
\def\E{{\cal E}}
\def\th{$^{\rm th}$\,}
\providecommand\upi{\pi}
\def\degr{^\circ}

\def\img#1#2{figs/#1}

%% hyperrefs

\def\url#1{{\tt #1}}
\chardef\tlde=`\~
\chardef\undrsc=`\_

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% new enviroments...

\def\beginitem{\begingroup\medskip}
\def\enditem{\medskip\endgroup}

%% intro
\newenvironment{intro}%
{%
  \par
  \noindent
  \small\em
  \ignorespaces
}
{%
  \par
  \smallskip
  \hrule
  \bigskip
}

%% publications and citations
\newcounter{pub}
\newcounter{cit}

\newenvironment{publications}%
{%

  \begin{list}{\arabic{pub}}{%
    \usecounter{pub}
    \topsep 2pt
    \itemsep 2pt
    \parsep 0pt
    \leftmargin .5cm
    \listparindent 0pt
    \labelwidth .5cm
  }
}
{%
  \end{list}
}

\newenvironment{citations}%
{%
  \footnotesize
  \parskip0pt
  \itemindent1cm
  \begin{list}{\arabic{cit}}{%
    \usecounter{cit}
    \topsep 2pt
    \itemsep 0pt
    \parsep 0pt
    \leftmargin .5cm
    \listparindent 0pt
    \labelwidth .5cm
  }
}
{%
  \end{list}
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% compatibility definitions for particular .tex files...

%% eos.tex
\def\colhead#1{\multicolumn{1}{c}{#1}}
\def\tablenotetext#1#2{\smallskip{\small $^{\rm #1}$#2\par}}
\def\tablehead#1{\hline#1\\}
\def\tablenotemark#1{$^{\rm #1}$}
\def\acknowledgments{\paragraph{Acknowledgments.}}
\let\tablecaption=\caption
\def\startdata{\hline}
\def\enddata{\hline}
\def\tablewidth#1{}

%% poznan.tex
\let\opencite=\cite
\let\citeyear=\cite
\let\inlinecite=\cite
\def\citeauthoryear#1#2{#1 (#2)}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% modification of other LaTeX macros...

%% bibitems from iaus.cls

\newif\if@altcite
\renewcommand\@biblabel[1]{}% FROM LATEX.LTX
%\newcommand\newblock{\hskip .11em \@plus .33em \@minus .07em\relax}
%\newcommand\bibls{\kern.065em\relax}

\newcount\refcontentnum\refcontentnum=1

\renewenvironment{thebibliography}[1]{%
  \par\vskip 20\p@ \@plus 1\p@ \@minus 1\p@
%  \centerline{\normalfont\small\scshape R\bibls E\bibls F\bibls E\bibls
%              R\bibls E\bibls N\bibls C\bibls E\bibls S}%
%\leftline{{\normalfont\bfseries References}}
  \section*{\refname}
  \addcontentsline{toc}{section}{\refname}
%  \ifnum\refcontentnum=1
%    \addcontentsline{toc}{subsection}{\refname}
%  \fi
  \nobreak
  \vskip 4\p@ \@plus .5\p@ \@minus .5\p@
  \nobreak
  \list{}{\labelwidth\z@ \leftmargin 2em \itemindent -2em \itemsep 1\p@}%
  \normalfont\small \parindent\z@
  \parskip\z@ \@plus .1\p@\relax
  \sloppy\clubpenalty\z@ \widowpenalty\@M
  \sfcode`\.\@m\relax}
  {\endlist}

\let\JFMthebib\thebibliography
\let\JFMendthebib\endthebibliography

\DeclareRobustCommand\cite{% FROM LATEX.LTX
  \@ifnextchar [{\@tempswatrue\global\@altcitetrue\@citex}
    {\@tempswafalse\global\@altcitefalse\@citex[]}}

\def\@citex[#1]#2{% FROM LATEX.LTX
  \let\@citea\@empty
  \@cite{\@for\@citeb:=#2\do
    {\@citea\def\@citea{,\penalty\@m\ }%
     \edef\@citeb{\expandafter\@firstofone\@citeb}%
     \if@filesw\immediate\write\@auxout{\string\citation{\@citeb}}\fi
     \@ifundefined{b@\@citeb}{\mbox{\reset@font\bfseries ?}%
       \G@refundefinedtrue
       \@latex@warning
         {Citation `\@citeb' on page \thepage \space undefined}}%
       {{\csname b@\@citeb\endcsname}}}}{#1}}

\renewcommand\@cite[2]{% FROM LATEX.LTX
  {\if@altcite #2\else #1\fi}\global\@altcitefalse}

%% end bibitems from iaus.cls


%% add Index in the TOC

\renewenvironment{theindex}
               {\if@twocolumn
                  \@restonecolfalse
                \else
                  \@restonecoltrue
                \fi
                \columnseprule \z@
                \columnsep 35\p@
                \twocolumn[%
  \section*{\indexname}%
  \addcontentsline{toc}{section}{\indexname}%
]%
                \@mkboth{\MakeUppercase\indexname}%
                        {\MakeUppercase\indexname}%
                \thispagestyle{plain}\parindent\z@
                \parskip\z@ \@plus .3\p@\relax
                \let\item\@idxitem}
               {\if@restonecol\onecolumn\else\clearpage\fi}


%% figure \caption is small

\long\def\@caption#1[#2]#3{%
  \par
  \addcontentsline{\csname ext@#1\endcsname}{#1}%
    {\protect\numberline{\csname the#1\endcsname}{\ignorespaces #2}}%
  \begingroup
    \@parboxrestore
    \if@minipage
      \@setminipage
    \fi
%    \normalsize
    \small
    \@makecaption{\csname fnum@#1\endcsname}{\ignorespaces #3}\par
  \endgroup}

\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{{\bf #1}: #2}%
  \ifdim \wd\@tempboxa >\hsize
    {\bf #1}: #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


